import { createOptions } from '../option/index.js';
import { createPrimitiveParser } from './parser.js';
import { isEqual } from './util.js';
const parseAsNull = (t) => createPrimitiveParser({
    t,
    expectedType: 'null',
    isMatchingType: () => t === null,
});
const parseAsString = (t) => createPrimitiveParser({
    t,
    expectedType: 'string',
    isMatchingType: () => isEqual('string', typeof t),
});
const parseAsBoolean = (t) => createPrimitiveParser({
    t,
    expectedType: 'boolean',
    isMatchingType: () => isEqual('boolean', typeof t),
});
const parseAsNumber = (t) => {
    const expectedType = 'number';
    const isMatchingType = () => isEqual(expectedType, typeof t);
    return {
        ...createPrimitiveParser({
            t,
            expectedType,
            isMatchingType,
        }),
        inRangeOf: (min, max) => {
            if (min > max || max < min) {
                throw new Error(`min must be less than max, max must also be greater than min. Min: ${min}, Max: ${max}`);
            }
            return createOptions({
                t: () => t,
                isMatchingType: () => {
                    if (!isMatchingType()) {
                        return false;
                    }
                    const n = t;
                    return n >= min && n <= max;
                },
            });
        },
    };
};
/**
 * Although it can be used to parse anything, this is recommended to be used to parse as a specified non-object type
 * @returns the Options object
 */
const parseAsCustomType = (t, isParseable) => createOptions({
    t: () => t,
    isMatchingType: () => isParseable(t),
});
export { parseAsBoolean, parseAsString, parseAsNumber, parseAsNull, parseAsCustomType, };
//# sourceMappingURL=primitive.js.map